@@ -1,10 +1,9 @@
 """ Convert doctree to Jupyter notebook
 """
-from __future__ import unicode_literals
-
 from docutils import nodes
 
-from .ipython_shim import nbf
+from nbformat import v4 as nbf
+
 from . import doctree2py as d2py
 
 
