@@ -2,8 +2,6 @@
 
 Test running writer over example files and chosen snippets.
 """
-from __future__ import (division, print_function, absolute_import,
-                        unicode_literals)
 
 from os.path import join as pjoin
 from glob import glob
