@@ -1,5 +1,4 @@
 """ Tests for build using nbplot extension """
-from __future__ import unicode_literals
 
 from os.path import (join as pjoin, dirname, isdir)
 import re
@@ -7,11 +6,15 @@ import os
 
 from docutils.nodes import paragraph, title
 
+import sphinx
+
+SPHINX_ge_1p8 = sphinx.version_info[:2] >= (1, 8)
+
 from nb2plots.nbplots import (run_code, parse_parts, nbplot_container,
                               nbplot_epilogue)
 from sphinxtesters import SourcesBuilder
 
-from nb2plots.testing import PlotsBuilder
+from nb2plots.testing import PlotsBuilder, OPT_TRANS
 
 from nb2plots.testing.nbtesters import assert_nb_equiv
 
@@ -20,6 +23,9 @@ import pytest
 
 HERE = dirname(__file__)
 
+# Variation in doctest block.
+DOCTEST_BLOCK_RE = r'<doctest_block (classes="doctest" )?xml:space="preserve">'
+
 
 def get_otherpage(fname):
     with open(pjoin(HERE, 'otherpages', fname), 'rt') as fobj:
@@ -445,21 +451,24 @@ See :ref:`the ref <a-ref>`.
         # Check that reference correctly included
         built = self.get_built_file('a_page.pseudoxml')
         expected_regexp = re.compile(
-r"""<document _plot_counter="1" source=".*?a_page.rst">
-    <section ids="a-title" names="a\\ title">
-        <title>
-            A title
-        <target ids="a-ref" names="a-ref">
-        <nbplot_container>
-            <doctest_block.*>
-                >>> a = 1
-        <nbplot_epilogue>
-            <.*>
-        <paragraph>
-            See\s
-            <reference internal="True" refid="a-ref">
-                <inline.*?>
-                    the ref
+            r'<document _plot_counter="1" source=".*?a_page.rst"'
+            rf'{OPT_TRANS}'
+            r'( xmlns:\w+=".*")*>'
+            r"""
+\s+<section ids="a-title" names="a\\ title">
+\s+    <title>
+\s+        A title
+\s+    <target ids="a-ref" names="a-ref">
+\s+    <nbplot_container>
+\s+        <doctest_block.*>
+\s+            >>> a = 1
+\s+    <nbplot_epilogue>
+\s+        <.*>
+\s+    <paragraph>
+\s+        See\s
+\s+        <reference internal="True" refid="a-ref">
+\s+            <inline.*?>
+\s+                the ref
             \.""", re.DOTALL)
         assert expected_regexp.match(built)
 
@@ -470,6 +479,12 @@ class TestFlags(PlotsBuilder):
 
     builder = 'pseudoxml'
 
+    literal_header = (
+        r'<literal_block ' +
+        (r'force(_highlighting)?="False" language="default" linenos="False" '
+        if SPHINX_ge_1p8 else '') +
+        'xml:space="preserve">')
+
     rst_sources=dict(a_page="""\
 A title
 -------
@@ -493,15 +508,17 @@ Some text
     def test_flags(self):
         # Check that flags correctly set from flag directives
         built = self.get_built_file('a_page.pseudoxml')
-        assert """
+        expected = r"""
         <title>
             A title
-        <literal_block xml:space="preserve">
-            {'a': 1, 'b': 2}
+        {literal_header}
+            {{'a': 1, 'b': 2}}
         <paragraph>
             Some text
-        <literal_block xml:space="preserve">
-            {'a': 1, 'b': 2, 'c': 3}""" in built
+        {literal_header}
+            {{'a': 1, 'b': 2, 'c': 3}}""".format(
+                literal_header=self.literal_header)
+        assert re.search(expected, built)
 
 
 class TestFlagsConfig(TestFlags):
@@ -515,16 +532,17 @@ nbplot_flags = {'flag1': 5, 'flag2': 6}
     def test_flags(self):
         # Check that global flags merged with local
         built = self.get_built_file('a_page.pseudoxml')
-        assert ("""
+        expected = r"""
         <title>
             A title
-        <literal_block xml:space="preserve">
-            {'a': 1, 'b': 2, 'flag1': 5, 'flag2': 6}
+        {literal_header}
+            {{'a': 1, 'b': 2, 'flag1': 5, 'flag2': 6}}
         <paragraph>
             Some text
-        <literal_block xml:space="preserve">
-            {'a': 1, 'b': 2, 'c': 3, 'flag1': 5, 'flag2': 6}"""
-                    in built)
+        {literal_header}
+            {{'a': 1, 'b': 2, 'c': 3, 'flag1': 5, 'flag2': 6}}""".format(
+                literal_header=self.literal_header)
+        assert re.search(expected, built)
 
 
 class TestWithoutSkip(PlotsBuilder):
@@ -626,7 +644,7 @@ class TestWithoutSkipStructure(TestWithoutSkip):
         <title>
             A title
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> # always
                 >>> a = 'default'
         <nbplot_epilogue>
@@ -636,7 +654,7 @@ class TestWithoutSkipStructure(TestWithoutSkip):
         <paragraph>
             Some text
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> a = 'skip is False'
         <nbplot_epilogue>
             <comment xml:space="preserve">
@@ -645,7 +663,7 @@ class TestWithoutSkipStructure(TestWithoutSkip):
         <paragraph>
             Keep text coming
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> b = 'skip appears to be False'
                 >>> a == 'skip is False'
                 True
@@ -656,10 +674,10 @@ class TestWithoutSkipStructure(TestWithoutSkip):
         <paragraph>
             Text continues
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> # doctest only run when skip flag False, always rendered
                 >>> b == 'skip appears to be False'
-                True""")
+                True""".format(**globals()))
         assert(regex.match(p_xml) is not None)
 
 
@@ -695,7 +713,7 @@ class TestWithSkipStructure(TestWithSkip):
         <title>
             A title
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> # always
                 >>> a = 'default'
         <nbplot_epilogue>
@@ -705,7 +723,7 @@ class TestWithSkipStructure(TestWithSkip):
         <paragraph>
             Some text
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> a = 'skip is True'
         <nbplot_epilogue>
             <comment xml:space="preserve">
@@ -714,7 +732,7 @@ class TestWithSkipStructure(TestWithSkip):
         <paragraph>
             Keep text coming
         <nbplot_container>
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> b = 'skip appears to be True'
                 >>> a == 'skip is True'
                 True
@@ -734,10 +752,10 @@ class TestWithSkipStructure(TestWithSkip):
             <comment xml:space="preserve">
             <comment xml:space="preserve">
         <nbplot_container hide-from="all" show-to="doctest">
-            <doctest_block xml:space="preserve">
+            {DOCTEST_BLOCK_RE}
                 >>> # only when skip flag True
                 >>> b == 'skip appears to be True'
-                True""")
+                True""".format(**globals()))
         assert(regex.match(p_xml) is not None)
 
 
